#!/bin/bash

#author				: hennes (jm@rapidrabbit.de)
#last changed		: 24-september-2007

#package			: widelands
#homepage			: http://xoops.widelands.org/

# ----- credentials
softname="widelands"
softversion="build11"
srcurl="http://downloads.sourceforge.net/widelands/widelands-build-11-source.tar.bz2"
arch=i486
cpu=i686
build="1"
zenversion="48"
packageversion="$zenversion.$build"

# ----- verify script
if [ "$(id -u)" != "0" ]; then
			echo "Please run as root!"
			exit 0
fi

# ----- help
if [ "${1}" = "--help" ]; then
	echo \
"$softname ZenBuild

usage:	--help 		Display this text
	--cleanup	Clean up after creating the package
"
	exit 0
fi

# ----- build parameters
numjobs="-j3"
builddir="$(pwd)"
package="$softname-$softversion-$arch-$packageversion"

# ----- prepare directories
dest="$builddir/$package"
rm -rf $dest
prefix="/usr"
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/$prefix/share/$softname
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/16x16/apps
mkdir -p $dest/usr/share/icons/hicolor/32x32/apps
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/share/icons/hicolor/64x64/apps
mkdir -p $dest/usr/share/icons/hicolor/128x128/apps
mkdir -p $dest/usr/doc/$softname-$softversion
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc

# ----- make slack-desc-file
cat << EOF > $dest/install/slack-desc
         |-----handy-ruler------------------------------------------------------|
widelands: widelands (realtime strategy game)
widelands:
widelands: In Widelands, you are the regent of a small tribe. You start out
widelands: with nothing but your headquarters, a kind of castle in which all
widelands: your resources are stored. In the course of the game, you will build
widelands: an ever growing settlement. Every member of your tribe will do his
widelands: or her part to produce more resources - wood, food, iron, gold and
widelands: more - to further this growth. But you are not alone in the world,
widelands: and you will meet other tribes sooner or later. Some of them may be
widelands: friendly and trade with you. However, if you want to rule the world,
widelands: you will have to train soldiers and fight.
EOF

# ----- extract source-archive
srcdir=$softname
rm -rf $srcdir
if [ -f $softname-build-11-source.tar.bz2 ]; then
   echo "looking for source-file .. found"
else
   echo "looking for source-file .. none found"
   wget -c $srcurl
fi
tar -jxvf $softname-build-11-source.tar.bz2
cd $srcdir

# ----- set target-permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;

# ----- patch for proper flags
#sed -i -e 's/-O3//' Makefile
sed -i -e 's/-O3/-O2/' build/scons-tools/scons_configure.py

# ----- scons build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
scons	install_prefix=$prefix \
		bindir=$prefix/bin \
		datadir=$prefix/share/$softname \
		localedir=$prefix/share \
		extra_compile_flags="-O2 -march=$arch -mtune=$cpu"
		
# ----- copy files
cp $softname $dest$prefix/bin
cp -R ./campaigns $dest$prefix/share/$softname
cp -R ./fonts $dest$prefix/share/$softname
cp -R ./game_server $dest$prefix/share/$softname
cp -R ./maps $dest$prefix/share/$softname
cp -R ./music $dest$prefix/share/$softname
cp -R ./pics $dest$prefix/share/$softname
cp -R ./sound $dest$prefix/share/$softname
cp -R ./tribes $dest$prefix/share/$softname
cp -R ./worlds $dest$prefix/share/$softname
cp -R ./locale $dest$prefix/share
cp ./doc/README* $dest$prefix/doc/$softname-$softversion
cp ./txts/COPYING $dest$prefix/doc/$softname-$softversion
cp ./txts/README $dest$prefix/doc/$softname-$softversion
cp ./txts/developers $dest$prefix/doc/$softname-$softversion
cp ./txts/editor_readme $dest$prefix/doc/$softname-$softversion
cp ./txts/gametips $dest$prefix/doc/$softname-$softversion

# ----- treat icon-file
cd $dest$prefix/share/icons/hicolor/16x16/apps
ln --symbolic ../../../../$softname/pics/wl-ico-16.png $softname.png
cd $dest$prefix/share/icons/hicolor/32x32/apps
ln --symbolic ../../../../$softname/pics/wl-ico-32.png $softname.png
cd $dest$prefix/share/icons/hicolor/48x48/apps
ln --symbolic ../../../../$softname/pics/wl-ico-48.png $softname.png
cd $dest$prefix/share/icons/hicolor/64x64/apps
ln --symbolic ../../../../$softname/pics/wl-ico-64.png $softname.png
cd $dest$prefix/share/icons/hicolor/128x128/apps
ln --symbolic ../../../../$softname/pics/wl-ico-128.png $softname.png

# ----- treat .desktop-file
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Widelands
Comment="Settlers II" clone
Comment[de]= Ein "Siedler II" Clone
Exec=widelands
Icon=widelands
Terminal=false
Type=Application
Categories=Game;StrategyGame;
Encoding=UTF-8
EOF

# ----- copy build-file
cp "$builddir/build-$softname.sh" "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"

# ----- post-build processing
cd $dest
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null

# ----- packaging
chown -R root.root $dest
cd $dest
makepkg -l y -c n $dest.tgz
cd ..
md5sum $package.tgz > $package.md5
cat << EOF > $package.dep
SDL_gfx,coreutils,cxxlibs,directfb,expat,fontconfig,freetype,gcc,gcc-g++,gdbm,libdrm,libjpeg,libpng,libtiff,mesa,ncurses,openssl,perl,sdl,sysfsutils,xorg,zlib
EOF

# ----- cleaning up
if [ "${1}" = "--cleanup" ]; then
rm -r $dest
rm -r $builddir/$srcdir
fi
